package com.mortals.xhx.feign.area;

import com.alibaba.fastjson.JSON;
import com.mortals.framework.common.Rest;
import com.mortals.xhx.common.pdu.SitePdu;
import com.mortals.xhx.feign.IFeign;
import com.mortals.xhx.module.area.model.AreaEntity;
import feign.hystrix.FallbackFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * 区域
 *
 * @author: zxfei
 * @date: 2022/5/30 10:40
 */
@FeignClient(name = "base-manager", path = "/zwfw", fallback = AreaFeignFallbackFactory.class)
public interface IApiAreaFeign extends IFeign {


    /**
     * 查看区域列表信息
     *
     * @param query
     * @return
     */
    @PostMapping(value = "/area/list")
    String list(@RequestBody AreaEntity query);


    /**
     * 查看区域信息
     *
     * @param id
     * @return
     */
    @GetMapping(value = "/area/info")
    String viewAreaInfo(@RequestParam(value = "id") Long id);


    /**
     * 删除区域信息
     *
     * @param ids
     * @return
     */
    @GetMapping(value = "/area/delete")
    String delete(Long[] ids,@RequestHeader("Authorization") String authorization);


    /**
     * 区域信息保存更新
     *
     * @param entity
     * @return
     */
    @PostMapping(value = "/area/save")
    String save(@RequestBody AreaEntity entity,@RequestHeader("Authorization") String authorization);

    /**
     * 查看区域子信息
     *
     * @param parentId 0为顶级
     * @return
     */
    @GetMapping(value = "/area/getListByParentId")
    String getListByParentId(@RequestParam(value = "parentId") String parentId);


    /**
     * 查看区域列表信息
     *
     * @return
     */
    @PostMapping(value = "/area/treeselect")
    String treeselect();


    /**
     * 根据区域id查询站点列表ids
     *
     * @param query
     * @return
     */
    @PostMapping(value = "/site/getFlatSitesByAreaIds")
    String getFlatSitesByAreaIds(@RequestBody SitePdu query);


}


@Slf4j
@Component
class  AreaFeignFallbackFactory implements FallbackFactory<IApiAreaFeign> {
    @Override
    public IApiAreaFeign create(Throwable t) {
        return new IApiAreaFeign() {
            @Override
            public String list(AreaEntity query) {
                return JSON.toJSONString(Rest.fail("暂时无法获取站点列表，请稍后再试!"));
            }

            @Override
            public String viewAreaInfo(Long id) {
                return JSON.toJSONString(Rest.fail("暂时无法获取站点列表，请稍后再试!"));
            }

            @Override
            public String delete(Long[] ids, String authorization) {
                return null;
            }

            @Override
            public String getListByParentId(String parentId) {
                return JSON.toJSONString(Rest.fail("暂时无法获取站点列表，请稍后再试!"));
            }

            @Override
            public String treeselect() {
                return JSON.toJSONString(Rest.fail("暂时无法获取站点列表，请稍后再试!"));
            }

            @Override
            public String getFlatSitesByAreaIds(SitePdu query) {
                return JSON.toJSONString(Rest.fail("暂时无法获取站点列表，请稍后再试!"));
            }

            @Override
            public String save(AreaEntity entity, String authorization) {
                return null;
            }


        };
    }
}

